pub struct Describe { /* private fields */ }Expand description
git configuration for the describe output
Implementations
Sourceimpl Describe
impl Describe
Instead of using only the annotated tags, use any tag found in refs/tags namespace.
Sourcepub fn dirty(&self) -> bool
pub fn dirty(&self) -> bool
If the working tree has local modification “-dirty” is appended to it.
Sourcepub fn match_pattern(&self) -> &Option<&'static str>
pub fn match_pattern(&self) -> &Option<&'static str>
Only consider tags matching the given glob pattern, excluding the “refs/tags/” prefix.